@@ -212,13 +212,30 @@
                         return;
                     }
 
-                    if (item.models) {
-                        item.models.forEach(child => {
-                            self.models.push(child);
-                        });
-                    } else {
-                        self.models.push(item);
+                    let models = [];
+
+                    function deep(menus) {
+                        menus.forEach(item => {
+                            //这是首页，不显示
+                            if (item.eid === "1") {
+                                return;
+                            }
+
+                            if (item.models) {
+                                deep(item.models);
+                            } else {
+                                //没有子级的时候，才加入到首页菜单中去
+                                models.push(item);
+                            }
+
+                        })
+
                     }
+
+                    deep(newValue);
+
+                    self.models = models;
+
                 });
             }
             /*,
@@ -309,7 +326,7 @@
                         item.models.forEach(mItem => {
                             mItem.icon = getIcon(mItem.name, mItem.icon);
                             self.menuData.push(mItem)
-                            if(mItem.models){
+                            if (mItem.models) {
                                 self.handlerMenus(mItem.models);
                             }
                         });
@@ -443,6 +460,11 @@
             }
             ,
             openTab: function (data, index, selected, loading) {
+                //support version: 2022.6.13
+                if (data.newTab) {
+                    window.open(data.url);
+                    return;
+                }
                 if (data.breadcrumbs) {
                     this.breadcrumbs = data.breadcrumbs;
                 }
@@ -593,7 +615,7 @@
             report: function (url) {
                 if (!url) {
                     if (document.querySelector('html').lang) {
-                        url = 'https://simpleui.88cto.com';
+                        url = 'https://simpleui.72wo.com';
                     } else {
                         url = 'https://github.com/newpanjing/simpleui/issues';
                     }
