@@ -12,7 +12,11 @@ from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
 from django.urls import reverse
-from django.utils.encoding import force_text
+
+try:
+    from django.utils.encoding import force_text
+except:
+    from django.utils.encoding import force_str as force_text
 from django.utils.functional import Promise
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
@@ -146,6 +150,15 @@ def __get_config(name):
     return value
 
 
+@register.simple_tag
+def get_setting(name):
+    """
+    获取设置项，默认为None
+    自2022.1版本开始增加该方法
+    """
+    return __get_config(name)
+
+
 @register.filter
 def get_config(key):
     return __get_config(key)
@@ -625,8 +638,6 @@ def get_current_app(request):
 @register.simple_tag(takes_context=True)
 def get_model_ajax_url(context):
     opts = context.get("opts")
-    request = context.get("request")
-
     key = "admin:{}_{}_ajax".format(opts.app_label, opts.model_name)
     try:
         return reverse(key)
